{
  config,
  pkgs,
  lib,
  ...
}: {
  imports = [
    # sway as windowmanager
    ../../modules/home-manager/sway.nix
    # zsh config
    ../../modules/home-manager/zsh.nix
    # foot terminal emulator
    ../../modules/home-manager/foot.nix
    # often used terminal programs
    ../../modules/home-manager/btop.nix
  ];

  # Home Manager needs a bit of information about you and the paths it should
  # manage.
  home.username = "max";
  home.homeDirectory = "/home/max";

  nixpkgs.config.allowUnfree = true;

  # This value determines the Home Manager release that your configuration is
  # compatible with. This helps avoid breakage when a new Home Manager release
  # introduces backwards incompatible changes.
  #
  # You should not change this value, even if you update Home Manager. If you do
  # want to update the value, then make sure to first check the Home Manager
  # release notes.
  home.stateVersion = "23.11"; # Please read the comment before changing.

  # The home.packages option allows you to install Nix packages into your
  # environment.
  home.packages = with pkgs; [
    lazygit
    bat
    unzip
    rustup
    nextcloud-client
    firefox
    thunderbird
    xournalpp
    kicad
    prismlauncher
    steam
    blender
    mpd
    mpdris2
    mpc-cli
    ymuse
    flip-link
    bacon
    probe-rs
    betaflight-configurator
    loudgain
    youtube-dl
    dconf
    distrobox
    gyroflow
    libqalculate
    sops
  ];

  # Home Manager is pretty good at managing dotfiles. The primary way to manage
  # plain files is through 'home.file'.
  home.file = {
    # # Building this configuration will create a copy of 'dotfiles/screenrc' in
    # # the Nix store. Activating the configuration will then make '~/.screenrc' a
    # # symlink to the Nix store copy.
    # ".screenrc".source = dotfiles/screenrc;

    # # You can also set the file content immediately.
    # ".gradle/gradle.properties".text = ''
    #   org.gradle.console=verbose
    #   org.gradle.daemon.idletimeout=3600000
    # '';
  };

  # Home Manager can also manage your environment variables through
  # 'home.sessionVariables'. If you don't want to manage your shell through Home
  # Manager then you have to manually source 'hm-session-vars.sh' located at
  # either
  #
  #  ~/.nix-profile/etc/profile.d/hm-session-vars.sh
  #
  # or
  #
  #  ~/.local/state/nix/profiles/profile/etc/profile.d/hm-session-vars.sh
  #
  # or
  #
  #  /etc/profiles/per-user/max/etc/profile.d/hm-session-vars.sh
  #
  home.sessionVariables = {
    EDITOR = "nvim";
  };

  services.nextcloud-client.enable = true;

  services.mpd = {
    enable = true;
    musicDirectory = "/home/max/Music/";
  };

  services.mpdris2.enable = true;

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;
}
